# WWW::SwaggerClient::CustomerApi

## Load the API package
```perl
use WWW::SwaggerClient::Object::CustomerApi;
```

All URIs are relative to *https://reputationcrm.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_customer_automatic**](CustomerApi.md#create_customer_automatic) | **POST** /createCustomerAutomatic | Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request)
[**create_customer_automatic_with_delay_review_request**](CustomerApi.md#create_customer_automatic_with_delay_review_request) | **POST** /createCustomerAutomaticWithDelayReviewRequest | Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request)
[**create_customer_immediate_first_review_request**](CustomerApi.md#create_customer_immediate_first_review_request) | **POST** /createCustomerImmediateFirstReviewRequest | Create a Customer AND Feedback / Review Requests
[**create_customer_manual_schedule_one_review_request**](CustomerApi.md#create_customer_manual_schedule_one_review_request) | **POST** /createCustomerManualScheduleOneReviewRequest | Create a Customer AND a one Feedback / Review Request (Manual Scheduling)
[**delete_customer**](CustomerApi.md#delete_customer) | **DELETE** /deleteCustomer | Delete ONE Customer record
[**get_all_customers_bycompany_id**](CustomerApi.md#get_all_customers_bycompany_id) | **GET** /getAllCustomersBycompanyId | Get Information on ALL Customers of a Company / Location / Feedback Page
[**get_customers_who_have_not_yet_submitted_review**](CustomerApi.md#get_customers_who_have_not_yet_submitted_review) | **GET** /getCustomersWhoHaveNotYetSubmittedReview | Get a list of Customers who have not yet submitted their Review / Feedback
[**get_single_customer**](CustomerApi.md#get_single_customer) | **GET** /getSingleCustomer | Get Information of ONE Customer
[**update_customer**](CustomerApi.md#update_customer) | **PUT** /updateCustomer | Update the record of ONE Customer


# **create_customer_automatic**
> string create_customer_automatic(companyid => $companyid, firstname => $firstname, lastname => $lastname, sendtype => $sendtype, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language, notes => $notes)

Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (No delay before sending the First Feedback / Review Request)

This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH NO DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -> Notifications -> Email AND SMS Tabs 

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::CustomerApi;
my $api_instance = WWW::SwaggerClient::CustomerApi->new(

    # Configure API key authorization: api_key
    api_key => {'key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'key' => 'Bearer'},
);

my $companyid = 'companyid_example'; # string | Company ID
my $firstname = 'firstname_example'; # string | Customer First Name
my $lastname = 'lastname_example'; # string | Customer Last Name
my $sendtype = 'sendtype_example'; # string | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\" 
my $email = 'email_example'; # string | Customer Email
my $mobile = 'mobile_example'; # string | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input 
my $address = 'address_example'; # string | Customer Postal Address
my $zipcode = 'zipcode_example'; # string | Customer Zipcode
my $city = 'city_example'; # string | Customer City
my $state = 'state_example'; # string | Customer State / Province / Region
my $country = 'country_example'; # string | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt 
my $language = 'language_example'; # string | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages 
my $notes = 'notes_example'; # string | Additional Customer Notes

eval { 
    my $result = $api_instance->create_customer_automatic(companyid => $companyid, firstname => $firstname, lastname => $lastname, sendtype => $sendtype, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language, notes => $notes);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling CustomerApi->create_customer_automatic: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **sendtype** | **string**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **string**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **string**| Additional Customer Notes | [optional] 

### Return type

**string**

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_customer_automatic_with_delay_review_request**
> create_customer_automatic_with_delay_review_request(companyid => $companyid, firstname => $firstname, lastname => $lastname, sendtype => $sendtype, delay_before_first_review_request => $delay_before_first_review_request, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language, notes => $notes)

Create a Customer AND a Feedback / Review Request Sequence with Automatic Scheduling (Set a Delay before sending the First Feedback / Review Request)

This API call creates a Customer in Reputation Builder, AND schedules an Automatic Email AND / OR SMS Feedback / Review Request Sequence, WITH A DELAY BEFORE SENDING THE FIRST FEEDBACK / REVIEW REQUEST, based on settings of the Company / Location -> Notifications -> Email AND SMS Tabs 

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::CustomerApi;
my $api_instance = WWW::SwaggerClient::CustomerApi->new(

    # Configure API key authorization: api_key
    api_key => {'key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'key' => 'Bearer'},
);

my $companyid = 'companyid_example'; # string | Company ID
my $firstname = 'firstname_example'; # string | Customer First Name
my $lastname = 'lastname_example'; # string | Customer Last Name
my $sendtype = 'sendtype_example'; # string | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\" 
my $delay_before_first_review_request = 'delay_before_first_review_request_example'; # string | Delay before sending the first Feedback / Review Request (Allowed values: \"immediately\", \"X minute\", \"X hour\", \"X day\", \"X week\", \"X month\", \"X year\") 
my $email = 'email_example'; # string | Customer Email
my $mobile = 'mobile_example'; # string | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input 
my $address = 'address_example'; # string | Customer Postal Address
my $zipcode = 'zipcode_example'; # string | Customer Zipcode
my $city = 'city_example'; # string | Customer City
my $state = 'state_example'; # string | Customer State / Province / Region
my $country = 'country_example'; # string | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt 
my $language = 'language_example'; # string | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages 
my $notes = 'notes_example'; # string | Additional Customer Notes

eval { 
    $api_instance->create_customer_automatic_with_delay_review_request(companyid => $companyid, firstname => $firstname, lastname => $lastname, sendtype => $sendtype, delay_before_first_review_request => $delay_before_first_review_request, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language, notes => $notes);
};
if ($@) {
    warn "Exception when calling CustomerApi->create_customer_automatic_with_delay_review_request: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **sendtype** | **string**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **delay_before_first_review_request** | **string**| Delay before sending the first Feedback / Review Request (Allowed values: \&quot;immediately\&quot;, \&quot;X minute\&quot;, \&quot;X hour\&quot;, \&quot;X day\&quot;, \&quot;X week\&quot;, \&quot;X month\&quot;, \&quot;X year\&quot;)  | 
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **string**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **string**| Additional Customer Notes | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_customer_immediate_first_review_request**
> create_customer_immediate_first_review_request(companyid => $companyid, firstname => $firstname, lastname => $lastname, sendtype => $sendtype, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language, notes => $notes)

Create a Customer AND Feedback / Review Requests

This API call creates a Customer in Reputation Builder AND Feedback / Review Request #1 (Email #1 AND/OR SMS #1 ONLY). Feedback / Review Request(s) are then sent immediately 

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::CustomerApi;
my $api_instance = WWW::SwaggerClient::CustomerApi->new(

    # Configure API key authorization: api_key
    api_key => {'key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'key' => 'Bearer'},
);

my $companyid = 'companyid_example'; # string | Company ID
my $firstname = 'firstname_example'; # string | Customer First Name
my $lastname = 'lastname_example'; # string | Customer Last Name
my $sendtype = 'sendtype_example'; # string | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\" 
my $email = 'email_example'; # string | Customer Email
my $mobile = 'mobile_example'; # string | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input 
my $address = 'address_example'; # string | Customer Postal Address
my $zipcode = 'zipcode_example'; # string | Customer Zipcode
my $city = 'city_example'; # string | Customer City
my $state = 'state_example'; # string | Customer State / Province / Region
my $country = 'country_example'; # string | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt 
my $language = 'language_example'; # string | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages 
my $notes = 'notes_example'; # string | Additional Customer Notes

eval { 
    $api_instance->create_customer_immediate_first_review_request(companyid => $companyid, firstname => $firstname, lastname => $lastname, sendtype => $sendtype, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language, notes => $notes);
};
if ($@) {
    warn "Exception when calling CustomerApi->create_customer_immediate_first_review_request: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **sendtype** | **string**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **string**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **string**| Additional Customer Notes | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_customer_manual_schedule_one_review_request**
> create_customer_manual_schedule_one_review_request(companyid => $companyid, firstname => $firstname, lastname => $lastname, sendtype => $sendtype, emailnumber => $emailnumber, smsnumber => $smsnumber, scheduledate => $scheduledate, scheduletime => $scheduletime, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language, notes => $notes)

Create a Customer AND a one Feedback / Review Request (Manual Scheduling)

This API call creates a Customer in Reputation Builder AND one Feedback / Review Request. You decide which Feedback / Review Request # to send, the sending method (Email or SMS) and you have full control of the sending date and time 

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::CustomerApi;
my $api_instance = WWW::SwaggerClient::CustomerApi->new(

    # Configure API key authorization: api_key
    api_key => {'key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'key' => 'Bearer'},
);

my $companyid = 'companyid_example'; # string | Company ID
my $firstname = 'firstname_example'; # string | Customer First Name
my $lastname = 'lastname_example'; # string | Customer Last Name
my $sendtype = 'sendtype_example'; # string | Feedback / Review Requests Sending Method (1 = Send via Email, 2 = Send via SMS, 1,2 = Send via Email AND SMS) Allowed values: \"1\", \"2\", \"1,2\" 
my $emailnumber = 'emailnumber_example'; # string | Set which Email Feedback / Requests will be sent (Allowed values: \"1\", \"2\", \"3\") 
my $smsnumber = 'smsnumber_example'; # string | Set which SMS Feedback / Requests will be sent (Allowed values: \"1\", \"2\", \"3\") 
my $scheduledate = 'scheduledate_example'; # string | Schedule date (yyyy/mm/dd) 
my $scheduletime = 'scheduletime_example'; # string | Schedule time (HH:MM 24 hours format) 
my $email = 'email_example'; # string | Customer Email
my $mobile = 'mobile_example'; # string | Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 = Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input 
my $address = 'address_example'; # string | Customer Postal Address
my $zipcode = 'zipcode_example'; # string | Customer Zipcode
my $city = 'city_example'; # string | Customer City
my $state = 'state_example'; # string | Customer State / Province / Region
my $country = 'country_example'; # string | Customer Country: has to be set to the name of the Country in its original language. Eg: Spain = EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt 
my $language = 'language_example'; # string | Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages 
my $notes = 'notes_example'; # string | Additional Customer Notes

eval { 
    $api_instance->create_customer_manual_schedule_one_review_request(companyid => $companyid, firstname => $firstname, lastname => $lastname, sendtype => $sendtype, emailnumber => $emailnumber, smsnumber => $smsnumber, scheduledate => $scheduledate, scheduletime => $scheduletime, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language, notes => $notes);
};
if ($@) {
    warn "Exception when calling CustomerApi->create_customer_manual_schedule_one_review_request: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **sendtype** | **string**| Feedback / Review Requests Sending Method (1 &#x3D; Send via Email, 2 &#x3D; Send via SMS, 1,2 &#x3D; Send via Email AND SMS) Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;1,2\&quot;  | [default to 1]
 **emailnumber** | **string**| Set which Email Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;)  | [default to 1]
 **smsnumber** | **string**| Set which SMS Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;)  | [default to 1]
 **scheduledate** | **string**| Schedule date (yyyy/mm/dd)  | 
 **scheduletime** | **string**| Schedule time (HH:MM 24 hours format)  | 
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone #: The Mobile Phone # must be formatted in its international version. Eg: +33647523335 (+33 &#x3D; Country Code for France). No leading Zero on Mobile Phone # usually (NOTE: some countries might a leading zero). Here is an excellent script for mobile number formatting: https://github.com/jackocnr/intl-tel-input  | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country: has to be set to the name of the Country in its original language. Eg: Spain &#x3D; EspaÃ±a. Download the sql file of all countries: https://reputationcrm.com/api/repcrm-api-docs/countries.txt  | [optional] 
 **language** | **string**| Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages  | [optional] 
 **notes** | **string**| Additional Customer Notes | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_customer**
> delete_customer(customerid => $customerid)

Delete ONE Customer record

This API call deletes an existing Customer from Reputation Builder. It will also delete all Email / SMS Requests still in the Queue

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::CustomerApi;
my $api_instance = WWW::SwaggerClient::CustomerApi->new(

    # Configure API key authorization: api_key
    api_key => {'key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'key' => 'Bearer'},
);

my $customerid = 'customerid_example'; # string | Customer ID

eval { 
    $api_instance->delete_customer(customerid => $customerid);
};
if ($@) {
    warn "Exception when calling CustomerApi->delete_customer: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customerid** | **string**| Customer ID | 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_all_customers_bycompany_id**
> ARRAY[Customer] get_all_customers_bycompany_id(companyid => $companyid)

Get Information on ALL Customers of a Company / Location / Feedback Page

This API call returns information from Reputation Builder on ALL existing Customers of a Company / Location / Feedback Page

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::CustomerApi;
my $api_instance = WWW::SwaggerClient::CustomerApi->new(

    # Configure API key authorization: api_key
    api_key => {'key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'key' => 'Bearer'},
);

my $companyid = 'companyid_example'; # string | Company ID

eval { 
    my $result = $api_instance->get_all_customers_bycompany_id(companyid => $companyid);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling CustomerApi->get_all_customers_bycompany_id: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 

### Return type

[**ARRAY[Customer]**](Customer.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_customers_who_have_not_yet_submitted_review**
> ARRAY[CustomerWhoHaveNotResponded] get_customers_who_have_not_yet_submitted_review(companyid => $companyid)

Get a list of Customers who have not yet submitted their Review / Feedback

This API call returns the list of Customers of a Company / Location / Feedback Page who have not yet responded to Feedback / Review Requests

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::CustomerApi;
my $api_instance = WWW::SwaggerClient::CustomerApi->new(

    # Configure API key authorization: api_key
    api_key => {'key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'key' => 'Bearer'},
);

my $companyid = 'companyid_example'; # string | Company ID

eval { 
    my $result = $api_instance->get_customers_who_have_not_yet_submitted_review(companyid => $companyid);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling CustomerApi->get_customers_who_have_not_yet_submitted_review: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 

### Return type

[**ARRAY[CustomerWhoHaveNotResponded]**](CustomerWhoHaveNotResponded.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_single_customer**
> ARRAY[Customer] get_single_customer(customerid => $customerid)

Get Information of ONE Customer

This API call returns information from Reputation Builder on ONE existing Customer

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::CustomerApi;
my $api_instance = WWW::SwaggerClient::CustomerApi->new(

    # Configure API key authorization: api_key
    api_key => {'key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'key' => 'Bearer'},
);

my $customerid = 'customerid_example'; # string | Customer ID

eval { 
    my $result = $api_instance->get_single_customer(customerid => $customerid);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling CustomerApi->get_single_customer: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customerid** | **string**| Customer ID | 

### Return type

[**ARRAY[Customer]**](Customer.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_customer**
> update_customer(customerid => $customerid, firstname => $firstname, lastname => $lastname, notes => $notes, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language)

Update the record of ONE Customer

This API call updates information from Reputation Builder on ONE existing Customer

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::CustomerApi;
my $api_instance = WWW::SwaggerClient::CustomerApi->new(

    # Configure API key authorization: api_key
    api_key => {'key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'key' => 'Bearer'},
);

my $customerid = 'customerid_example'; # string | Customer ID
my $firstname = 'firstname_example'; # string | Customer First Name
my $lastname = 'lastname_example'; # string | Customer Last Name
my $notes = 'notes_example'; # string | Additional Customer Notes
my $email = 'email_example'; # string | Customer Email
my $mobile = 'mobile_example'; # string | Customer Mobile Phone
my $address = 'address_example'; # string | Customer Postal Address
my $zipcode = 'zipcode_example'; # string | Customer Zipcode
my $city = 'city_example'; # string | Customer City
my $state = 'state_example'; # string | Customer State / Province / Region
my $country = 'country_example'; # string | Customer Country
my $language = 'language_example'; # string | Customer Language

eval { 
    $api_instance->update_customer(customerid => $customerid, firstname => $firstname, lastname => $lastname, notes => $notes, email => $email, mobile => $mobile, address => $address, zipcode => $zipcode, city => $city, state => $state, country => $country, language => $language);
};
if ($@) {
    warn "Exception when calling CustomerApi->update_customer: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **customerid** | **string**| Customer ID | 
 **firstname** | **string**| Customer First Name | 
 **lastname** | **string**| Customer Last Name | 
 **notes** | **string**| Additional Customer Notes | 
 **email** | **string**| Customer Email | [optional] 
 **mobile** | **string**| Customer Mobile Phone | [optional] 
 **address** | **string**| Customer Postal Address | [optional] 
 **zipcode** | **string**| Customer Zipcode | [optional] 
 **city** | **string**| Customer City | [optional] 
 **state** | **string**| Customer State / Province / Region | [optional] 
 **country** | **string**| Customer Country | [optional] 
 **language** | **string**| Customer Language | [optional] 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json, application/xml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

